@@ -15,7 +15,7 @@
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-/* $Id: platform.h.in,v 1.16.4.2 2001/02/21 00:15:15 gson Exp $ */
+/* $Id: platform.h.in,v 1.16.4.4 2001/06/14 13:37:45 gson Exp $ */
 
 #ifndef ISC_PLATFORM_H
 #define ISC_PLATFORM_H 1
@@ -56,7 +56,7 @@
  * If this system is missing in6addr_any, ISC_PLATFORM_NEEDIN6ADDRANY will
  * be defined.
  */
-#undef ISC_PLATFORM_NEEDIN6ADDRANY
+#define ISC_PLATFORM_NEEDIN6ADDRANY 1
 
 /*
  * If this system has in6_pktinfo, ISC_PLATFORM_HAVEIN6PKTINFO will be
@@ -73,12 +73,12 @@
 /*
  * If this system needs inet_ntop(), ISC_PLATFORM_NEEDNTOP will be defined.
  */
-#undef ISC_PLATFORM_NEEDNTOP
+#define ISC_PLATFORM_NEEDNTOP 1
 
 /*
  * If this system needs inet_pton(), ISC_PLATFORM_NEEDPTON will be defined.
  */
-#undef ISC_PLATFORM_NEEDPTON
+#define ISC_PLATFORM_NEEDPTON 1
 
 /*
  * If this system needs inet_aton(), ISC_PLATFORM_NEEDATON will be defined.
@@ -88,7 +88,7 @@
 /*
  * If this system needs in_port_t, ISC_PLATFORM_NEEDPORTT will be defined.
  */
-#undef ISC_PLATFORM_NEEDPORTT
+#define ISC_PLATFORM_NEEDPORTT 1
 
 /*
  * If the system needs strsep(), ISC_PLATFORM_NEEDSTRSEP will be defined.
@@ -130,7 +130,17 @@
 /*
  * Defined if we are using threads.
  */
-#undef ISC_PLATFORM_USETHREADS
+#define ISC_PLATFORM_USETHREADS 1
+
+/*
+ * Type used for resource limits.
+ */
+#define ISC_PLATFORM_RLIMITTYPE long long int
+
+/*
+ * Defined if unistd.h does not cause fd_set to be delared.
+ */
+#undef ISC_PLATFORM_NEEDSYSSELECTH
 
 /*
  * Tell emacs to use C mode for this file.
