@@ -54,7 +54,7 @@
  * If this system is missing in6addr_any, LWRES_PLATFORM_NEEDIN6ADDRANY will
  * be defined.
  */
-#undef LWRES_PLATFORM_NEEDIN6ADDRANY
+#define LWRES_PLATFORM_NEEDIN6ADDRANY 1
 
 /*
  * If this system has in_addr6, rather than in6_addr,
